@@ -75,6 +75,9 @@ class TelegramLogger:
         self.add(msg)
         self.flush()
 
+    def __call__(self, msg: str = "") -> None:
+        self.send(msg)
+
     @staticmethod
     def format_msg(msg: str = "") -> str:
         """TODO
